@@ -443,6 +443,11 @@ def volume_get_all_by_host(context, host, filters=None):
     return IMPL.volume_get_all_by_host(context, host, filters=filters)
 
 
+def volume_update_all_by_service(context):
+    """Update all volumes associated with an old service."""
+    return IMPL.volume_update_all_by_service(context)
+
+
 def volume_get_all_by_group(context, group_id, filters=None):
     """Get all volumes belonging to a consistency group."""
     return IMPL.volume_get_all_by_group(context, group_id, filters=filters)
@@ -514,11 +519,9 @@ def volume_attachment_get(context, attachment_id):
     return IMPL.volume_attachment_get(context, attachment_id)
 
 
-def volume_attachment_get_all_by_volume_id(context, volume_id,
-                                           session=None):
+def volume_attachment_get_all_by_volume_id(context, volume_id):
     return IMPL.volume_attachment_get_all_by_volume_id(context,
-                                                       volume_id,
-                                                       session)
+                                                       volume_id)
 
 
 def volume_attachment_get_all_by_host(context, host, filters=None):
@@ -1033,8 +1036,8 @@ def group_type_specs_update_or_create(context,
 ###################
 
 
-def volume_type_encryption_get(context, volume_type_id, session=None):
-    return IMPL.volume_type_encryption_get(context, volume_type_id, session)
+def volume_type_encryption_get(context, volume_type_id):
+    return IMPL.volume_type_encryption_get(context, volume_type_id)
 
 
 def volume_type_encryption_delete(context, volume_type_id):
@@ -1051,13 +1054,12 @@ def volume_type_encryption_update(context, volume_type_id, encryption_specs):
                                               encryption_specs)
 
 
-def volume_type_encryption_volume_get(context, volume_type_id, session=None):
-    return IMPL.volume_type_encryption_volume_get(context, volume_type_id,
-                                                  session)
+def volume_type_encryption_volume_get(context, volume_type_id):
+    return IMPL.volume_type_encryption_volume_get(context, volume_type_id)
 
 
-def volume_encryption_metadata_get(context, volume_id, session=None):
-    return IMPL.volume_encryption_metadata_get(context, volume_id, session)
+def volume_encryption_metadata_get(context, volume_id):
+    return IMPL.volume_encryption_metadata_get(context, volume_id)
 
 
 ###################
@@ -1787,9 +1789,6 @@ def driver_initiator_data_insert_by_key(context, initiator,
     """Updates DriverInitiatorData entry.
 
     Sets the value for the specified key within the namespace.
-
-    If the entry already exists return False, if it inserted successfully
-    return True.
     """
     return IMPL.driver_initiator_data_insert_by_key(context,
                                                     initiator,
@@ -1892,17 +1891,6 @@ def cleanup_expired_messages(context):
 ###################
 
 
-def workers_init():
-    """Check if DB supports subsecond resolution and set global flag.
-
-    MySQL 5.5 doesn't support subsecond resolution in datetime fields, so we
-    have to take it into account when working with the worker's table.
-
-    Once we drop support for MySQL 5.5 we can remove this method.
-    """
-    return IMPL.workers_init()
-
-
 def worker_create(context, **values):
     """Create a worker entry from optional arguments."""
     return IMPL.worker_create(context, **values)
