@@ -28,6 +28,7 @@ from oslo_utils import units
 import paramiko
 import six
 
+from cinder.common import constants
 from cinder import context
 from cinder import exception
 from cinder.i18n import _
@@ -856,7 +857,7 @@ class GPFSDriver(driver.CloneableImageVD,
         data["volume_backend_name"] = backend_name or 'GPFS'
         data["vendor_name"] = 'IBM'
         data["driver_version"] = self.VERSION
-        data["storage_protocol"] = 'file'
+        data["storage_protocol"] = constants.FILE
         free, capacity = self._get_available_capacity(self.configuration.
                                                       gpfs_mount_point_base)
         data['total_capacity_gb'] = math.ceil(capacity / units.Gi)
@@ -949,7 +950,8 @@ class GPFSDriver(driver.CloneableImageVD,
 
         return {'provider_location': None}, True
 
-    def copy_image_to_volume(self, context, volume, image_service, image_id):
+    def copy_image_to_volume(self, context, volume, image_service, image_id,
+                             disable_sparse=False):
         """Fetch the image from image_service and write it to the volume.
 
         Note that cinder.volume.flows.create_volume will attempt to use
@@ -966,7 +968,8 @@ class GPFSDriver(driver.CloneableImageVD,
         image_utils.fetch_to_raw(context, image_service, image_id,
                                  self.local_path(volume),
                                  self.configuration.volume_dd_blocksize,
-                                 size=volume['size'])
+                                 size=volume['size'],
+                                 disable_sparse=disable_sparse)
         self._resize_volume_file(volume, volume['size'])
 
     def _resize_volume_file(self, volume, new_size):
@@ -1561,7 +1564,7 @@ class GPFSNFSDriver(GPFSDriver, nfs.NfsDriver, san.SanDriver):
         data['volume_backend_name'] = backend_name or 'GPFSNFS'
         data['vendor_name'] = 'IBM'
         data['driver_version'] = self.get_version()
-        data['storage_protocol'] = 'file'
+        data['storage_protocol'] = constants.FILE
 
         self._ensure_shares_mounted()
 
